Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5224)

Unified Diff: chrome/browser/browser.h

Issue 341043: Changes session restore to use a normal load rather than preferring... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/browser.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/browser.h
===================================================================
--- chrome/browser/browser.h (revision 30525)
+++ chrome/browser/browser.h (working copy)
@@ -256,12 +256,14 @@
// system. If select is true, the tab is selected. |tab_index| gives the index
// to insert the tab at. |selected_navigation| is the index of the
// TabNavigation in |navigations| to select. If |pin| is true and |tab_index|
// is the last pinned tab, then the newly created tab is pinned.
TabContents* AddRestoredTab(const std::vector<TabNavigation>& navigations,
int tab_index,
int selected_navigation,
bool select,
- bool pin);
+ bool pin,
+ bool from_last_session);
// Creates a new tab with the already-created TabContents 'new_contents'.
// The window for the added contents will be reparented correctly when this
// method returns. If |disposition| is NEW_POPUP, |pos| should hold the
@@ -294,7 +296,8 @@
// history restored from the SessionRestore system.
void ReplaceRestoredTab(
const std::vector<TabNavigation>& navigations,
- int selected_navigation);
+ int selected_navigation,
+ bool from_last_session);
// Returns true if a tab can be restored.
virtual bool CanRestoreTab();
@@ -623,12 +626,6 @@
// >= index.
void SyncHistoryWithTabs(int index);
- // Called from AddRestoredTab and ReplaceRestoredTab to build a
- // TabContents from an incoming vector of TabNavigations.
- // Caller takes ownership of the returned TabContents.
- TabContents* BuildRestoredTab(const std::vector<TabNavigation>& navigations,
- int selected_navigation);
-
// OnBeforeUnload handling //////////////////////////////////////////////////
typedef std::set<TabContents*> UnloadListenerSet;
« no previous file with comments | « no previous file | chrome/browser/browser.cc » ('j') | no next file with comments »
@@ -256,12 +256,14 @@
// to insert the tab at. |selected_navigation| is the index of the
// TabNavigation in |navigations| to select. If |pin| is true and |tab_index|
- // is the last pinned tab, then the newly created tab is pinned.
+ // is the last pinned tab, then the newly created tab is pinned. If
+ // |from_last_session| is true, |navigations| are from the previous session.
TabContents* AddRestoredTab(const std::vector<TabNavigation>& navigations,
int tab_index,

Powered by Google App Engine
This is Rietveld 408576698